<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../aboutdialog.cpp" line="23"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="26"/>
        <source>Launch application with image file path as argument to load the file.</source>
        <translation>Lancer l&apos;application avec le chemin du fichier image comme argument pour charger le fichier.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="27"/>
        <source>Drag and drop image file onto the window is also supported.</source>
        <translation>Le glisser-déposer du fichier image sur la fenêtre est également pris en charge.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="28"/>
        <source>None of the operations in this application will alter the pictures on disk.</source>
        <translation>Aucun opération dans cette application ne modifiera les fichiers image.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="29"/>
        <source>Context menu option explanation:</source>
        <translation>Explication des options du menu contextuel&#xa0;:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="36"/>
        <source>Make window stay on top of all other windows.</source>
        <translation>Faire en sorte que la fenêtre reste au-dessus de toutes les autres fenêtres.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="39"/>
        <source>Avoid close window accidentally. (eg. by double clicking the window)</source>
        <translation>Éviter de fermer la fenêtre accidentellement. (par exemple en cliquant deux fois sur la fenêtre)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="47"/>
        <source>Version: %1</source>
        <translation>Version&#xa0;: %1</translation>
    </message>
    <message>
        <source>Copyright (c) 2020 %1</source>
        <translation type="vanished">Copyright © 2020 %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="53"/>
        <source>Logo designed by %1</source>
        <translation>Logo conçu par %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="55"/>
        <source>Built with Qt %1 (%2)</source>
        <translation>Fait avec Qt %1 (%2)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="56"/>
        <source>Source code</source>
        <translation>Code source</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="66"/>
        <source>Contributors</source>
        <translation>Contributeurs</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="68"/>
        <source>List of contributors on GitHub</source>
        <translation>Liste des contributeurs sur GitHub</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="69"/>
        <source>Thanks to all people who contributed to this project.</source>
        <translation>Merci à toutes les personnes qui ont contribué à ce projet.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="73"/>
        <source>Translators</source>
        <translation>Traducteurs</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="74"/>
        <source>I would like to thank the following people who volunteered to translate this application.</source>
        <translation>Je tiens à remercier les personnes suivantes qui se sont portées volontaires pour traduire cette application.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="118"/>
        <source>%1 is built on the following free software libraries:</source>
        <comment>Free as in freedom</comment>
        <translation>%1 est basé sur les bibliothèques de logiciels libres suivantes&#xa0;:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="142"/>
        <source>&amp;Special Thanks</source>
        <translation>&amp;Remerciement spécial</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="144"/>
        <source>&amp;Third-party Libraries</source>
        <translation>&amp;Bibliothèques tierces</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="80"/>
        <source>Your Rights</source>
        <translation>Vos droits</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="50"/>
        <source>Copyright (c) %1 %2</source>
        <comment>%1 is year, %2 is the name of copyright holder(s)</comment>
        <translation>Copyright (c) %1 %2</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="82"/>
        <source>%1 is released under the MIT License.</source>
        <translation>%1 est publié sous licence MIT.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="83"/>
        <source>This license grants people a number of freedoms:</source>
        <translation>Cette licence accorde aux personnes un certain nombre de libertés&#xa0;:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="84"/>
        <source>You are free to use %1, for any purpose</source>
        <translation>Vous êtes libre d&apos;utiliser %1, dans n&apos;importe quel but</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="85"/>
        <source>You are free to distribute %1</source>
        <translation>Vous êtes libre de distribuer %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="86"/>
        <source>You can study how %1 works and change it</source>
        <translation>Vous pouvez étudier le fonctionnement de %1 et le modifier</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="87"/>
        <source>You can distribute changed versions of %1</source>
        <translation>Vous pouvez distribuer des versions modifiées de %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="89"/>
        <source>The MIT license guarantees you this freedom. Nobody is ever permitted to take it away.</source>
        <translation>La licence MIT vous garantit cette liberté. Personne n&apos;est autorisé à l&apos;enlever.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="117"/>
        <source>Third-party Libraries used by %1</source>
        <translation>Bibliothèques tierces utilisées par %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="140"/>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="141"/>
        <source>&amp;About</source>
        <translation>&amp;À propos</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="143"/>
        <source>&amp;License</source>
        <translation>&amp;Licence</translation>
    </message>
</context>
<context>
    <name>GraphicsScene</name>
    <message>
        <location filename="../graphicsscene.cpp" line="57"/>
        <source>Drag image here</source>
        <translation>Faites glisser l&apos;image ici</translation>
    </message>
</context>
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../graphicsview.cpp" line="333"/>
        <source>File url list is empty</source>
        <translation>La liste des URL du fichier est vide</translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="52"/>
        <source>File is not a valid image</source>
        <translation>Le fichier n&apos;est pas une image valide</translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="57"/>
        <location filename="../graphicsview.cpp" line="62"/>
        <source>Image data is invalid or currently unsupported</source>
        <translation>Les données d&apos;image ne sont pas valides ou ne sont actuellement pas prises en charge</translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="341"/>
        <source>Image data is invalid</source>
        <translation>Les données d&apos;image ne sont pas valides</translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="348"/>
        <source>Not supported mimedata: %1</source>
        <translation>Mimedata non pris en charge&#xa0;: %1</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="160"/>
        <source>File url list is empty</source>
        <translation>La liste des URL de fichiers est vide</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="403"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copier</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="83"/>
        <source>Copy P&amp;ixmap</source>
        <translation>Copier P&amp;ixmap</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="84"/>
        <source>Copy &amp;File Path</source>
        <translation>Copier le &amp;chemin du fichier</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="100"/>
        <source>Properties</source>
        <translation>Propriétés</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="35"/>
        <location filename="../actionmanager.cpp" line="86"/>
        <source>Stay on top</source>
        <translation>Rester en-haut</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="38"/>
        <location filename="../actionmanager.cpp" line="87"/>
        <source>Protected mode</source>
        <translation>Mode protégé</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="72"/>
        <source>Zoom in</source>
        <translation>Zoom avant</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="73"/>
        <source>Zoom out</source>
        <translation>Zoom arrière</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="80"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Retourner &amp;horizontalement</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="85"/>
        <source>&amp;Paste</source>
        <translation>Co&amp;ller</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="74"/>
        <source>Toggle Checkerboard</source>
        <translation>Dés/activer le damier</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="68"/>
        <source>&amp;Open...</source>
        <translation>&amp;Ouvrir...</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="70"/>
        <source>Actual size</source>
        <translation>Taille actuelle</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="71"/>
        <source>Toggle maximize</source>
        <translation>Dés/activer l&apos;agrandissement</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="75"/>
        <source>Rotate right</source>
        <translation>Pivoter vers la droite</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="77"/>
        <source>Previous image</source>
        <translation>Image précédente</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="78"/>
        <source>Next image</source>
        <translation>Image suivant</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="88"/>
        <source>Configure...</source>
        <translation>Configurer…</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="89"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="92"/>
        <source>Show in File Explorer</source>
        <comment>File Explorer is the name of explorer.exe under Windows</comment>
        <translation>Afficher dans le navigateur de fichiers</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="98"/>
        <source>Show in directory</source>
        <translation>Afficher dans le dossier</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="101"/>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
</context>
<context>
    <name>MetadataDialog</name>
    <message>
        <location filename="../metadatadialog.cpp" line="80"/>
        <source>Image Metadata</source>
        <translation>Métadonnées d&apos;image</translation>
    </message>
</context>
<context>
    <name>MetadataModel</name>
    <message>
        <location filename="../metadatamodel.cpp" line="37"/>
        <source>Origin</source>
        <comment>Section name.</comment>
        <translation>Origine</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="38"/>
        <source>Image</source>
        <comment>Section name.</comment>
        <translation>Image</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="42"/>
        <source>File</source>
        <comment>Section name.</comment>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="39"/>
        <source>Camera</source>
        <comment>Section name.</comment>
        <translation>Appareil photo</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="29"/>
        <source>%1 File</source>
        <translation>Fichier %1</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="36"/>
        <source>Description</source>
        <comment>Section name.</comment>
        <translation>Description</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="40"/>
        <source>Advanced photo</source>
        <comment>Section name.</comment>
        <translation>Photo avancée</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="41"/>
        <source>GPS</source>
        <comment>Section name.</comment>
        <translation>GPS</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="46"/>
        <source>Dimensions</source>
        <translation>Dimensions</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="48"/>
        <source>Aspect ratio</source>
        <translation>Rapport d&apos;aspect</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="52"/>
        <source>Frame count</source>
        <translation>Nombre d&apos;images</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="56"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="58"/>
        <source>Item type</source>
        <translation>Type d&apos;élément</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="60"/>
        <source>Folder path</source>
        <translation>Chemin du dossier</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="62"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="64"/>
        <source>Date created</source>
        <translation>Date créée</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="66"/>
        <source>Date modified</source>
        <translation>Date modifiée</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="73"/>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="75"/>
        <source>Subject</source>
        <translation>Sujet</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="77"/>
        <source>Rating</source>
        <translation>Évaluation</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="79"/>
        <source>Tags</source>
        <translation>Étiquettes</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="81"/>
        <source>Comments</source>
        <translation>Commentaires</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="84"/>
        <source>Authors</source>
        <translation>Auteurs</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="86"/>
        <source>Date taken</source>
        <translation>Date prise</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="92"/>
        <source>Program name</source>
        <translation>Nom du programme</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="94"/>
        <source>Copyright</source>
        <translation>Copyright</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="97"/>
        <source>Horizontal resolution</source>
        <translation>Résolution horizontale</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="99"/>
        <source>Vertical resolution</source>
        <translation>Résolution verticale</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="101"/>
        <source>Resolution unit</source>
        <translation>Unité de résolution</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="103"/>
        <source>Colour representation</source>
        <translation>Représentation des couleurs</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="106"/>
        <source>Camera maker</source>
        <translation>Fabricant de l&apos;appareil photo</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="108"/>
        <source>Camera model</source>
        <translation>Modèle d&apos;appareil photo</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="110"/>
        <source>F-stop</source>
        <translation>Nombre d&apos;ouverture</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="112"/>
        <source>Exposure time</source>
        <translation>Temps d&apos;exposition</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="114"/>
        <source>ISO speed</source>
        <translation>Vitesse ISO</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="116"/>
        <source>Exposure bias</source>
        <translation>Biais d&apos;exposition</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="118"/>
        <source>Focal length</source>
        <translation>Distance focale</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="120"/>
        <source>Max aperture</source>
        <translation>Ouverture maximale</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="122"/>
        <source>Metering mode</source>
        <translation>Mode de mesure</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="124"/>
        <source>Flash mode</source>
        <translation>Mode flash</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="126"/>
        <source>35mm focal length</source>
        <translation>Distance focale de 35&#xa0;mm</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="129"/>
        <source>Lens model</source>
        <translation>Modèle d&apos;objectif</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="131"/>
        <source>Brightness</source>
        <translation>Luminosité</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="133"/>
        <source>Exposure program</source>
        <translation>Programme d&apos;exposition</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="135"/>
        <source>Saturation</source>
        <translation>Saturation</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="137"/>
        <source>Sharpness</source>
        <translation>Netteté</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="139"/>
        <source>White balance</source>
        <translation>Balance des blancs</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="141"/>
        <source>Digital zoom</source>
        <translation>Zoom numérique</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="143"/>
        <source>EXIF version</source>
        <translation>Version EXIF</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="146"/>
        <source>Latitude reference</source>
        <translation>Référence de latitude</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="148"/>
        <source>Latitude</source>
        <translation>Latitude</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="150"/>
        <source>Longitude reference</source>
        <translation>Référence de longitude</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="152"/>
        <source>Longitude</source>
        <translation>Longitude</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="154"/>
        <source>Altitude reference</source>
        <translation>Référence d&apos;altitude</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="156"/>
        <source>Altitude</source>
        <translation>Altitude</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="166"/>
        <source>%1 x %2</source>
        <translation>%1 × %2</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="184"/>
        <source>%1 : %2</source>
        <translation>%1 : %2</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="309"/>
        <source>Property</source>
        <translation>Propriété</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="309"/>
        <source>Value</source>
        <translation>Valeur</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="17"/>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="22"/>
        <source>Do nothing</source>
        <translation>Ne rien faire</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="23"/>
        <source>Close the window</source>
        <translation>Fermer la fenêtre</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="24"/>
        <source>Toggle maximize</source>
        <translation>Activer/désactiver l&apos;agrandissement</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="28"/>
        <source>Zoom in and out</source>
        <translation>Zoom avant et arrière</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="29"/>
        <source>View next or previous item</source>
        <translation>Voir l&apos;élément suivant ou précédent</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="33"/>
        <source>Auto size</source>
        <translation>Taille automatique</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="34"/>
        <source>Maximized</source>
        <translation>Agrandi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="52"/>
        <source>Stay on top when start-up</source>
        <translation>Rester en-haut lors du démarrage</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="53"/>
        <source>Double-click behavior</source>
        <translation>Comportement du double-clic</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="54"/>
        <source>Mouse wheel behavior</source>
        <translation>Comportement de la molette de la souris</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="55"/>
        <source>Default window size</source>
        <translation>Taille de la fenêtre par défaut</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="31"/>
        <source>Pineapple Pictures</source>
        <translation>Pineapple Pictures</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="35"/>
        <source>File list.</source>
        <translation>Liste des fichiers.</translation>
    </message>
</context>
</TS>
